@@ -42,6 +42,7 @@ CRQWiz::CRQWiz(TQSL_CERT_REQ *crq, tQSL_Cert xcert, wxWindow *parent, wxHtmlHelp
 	dxcc = -1;
 	validcerts = false;		// No signing certs to use
 	onebyone = false;
+	forceSigning = false;		// Not portable
 	renewal = (_crq != NULL);	// It's a renewal if there's a CRQ provided
 	usa = validusa = false;		// Not usa
 	// Get count of valid certificates
@@ -109,8 +110,10 @@ CRQ_ProviderPage::CRQ_ProviderPage(CRQWiz *parent, TQSL_CERT_REQ *crq) :  CRQ_Pa
 	sizer->Add(st, 0, wxALL, 10);
 
 	sizer->Add(new wxStaticText(this, -1, _("Certificate Issuer:")), 0, wxLEFT|wxRIGHT, 10);
-	tc_provider = new wxOwnerDrawnComboBox(this, ID_CRQ_PROVIDER, wxT(""), wxDefaultPosition,
+	tc_provider = new tqslComboBox(this, ID_CRQ_PROVIDER, wxT(""), wxDefaultPosition,
 		wxDefaultSize, 0, 0, wxCB_DROPDOWN|wxCB_READONLY);
+	ACCESSIBLE(tc_provider, ComboBoxAx);
+	tc_provider->SetName(wxT("Certificate Issuer"));
 	sizer->Add(tc_provider, 0, wxLEFT|wxRIGHT|wxEXPAND, 10);
 	tc_provider_info = new wxStaticText(this, ID_CRQ_PROVIDER_INFO, wxT(""), wxDefaultPosition,
 		wxSize(0, em_h*5));
@@ -175,6 +178,13 @@ static wxDateTime::Month mons[] = {
 
 BEGIN_EVENT_TABLE(CRQ_CallsignPage, CRQ_Page)
 	EVT_TEXT(ID_CRQ_CALL, CRQ_Page::check_valid)
+	EVT_TEXT(ID_CRQ_DXCC, tqslComboBox::OnTextEntry)
+	EVT_TEXT(ID_CRQ_QBYEAR, tqslComboBox::OnTextEntry)
+	EVT_TEXT(ID_CRQ_QBMONTH, tqslComboBox::OnTextEntry)
+	EVT_TEXT(ID_CRQ_QBDAY, tqslComboBox::OnTextEntry)
+	EVT_TEXT(ID_CRQ_QEYEAR, tqslComboBox::OnTextEntry)
+	EVT_TEXT(ID_CRQ_QEMONTH, tqslComboBox::OnTextEntry)
+	EVT_TEXT(ID_CRQ_QEDAY, tqslComboBox::OnTextEntry)
 	EVT_COMBOBOX(ID_CRQ_DXCC, CRQ_Page::check_valid)
 	EVT_COMBOBOX(ID_CRQ_QBYEAR, CRQ_Page::check_valid)
 	EVT_COMBOBOX(ID_CRQ_QBMONTH, CRQ_Page::check_valid)
@@ -205,6 +215,8 @@ CRQ_CallsignPage::CRQ_CallsignPage(CRQWiz *parent, TQSL_CERT_REQ *crq) :  CRQ_Pa
 		cs = wxString::FromUTF8(crq->callSign);
 	tc_call = new wxTextCtrl(this, ID_CRQ_CALL, cs, wxDefaultPosition, wxSize(em_w*15, -1));
 	tc_call->SetMaxLength(TQSL_CALLSIGN_MAX);
+	ACCESSIBLE(tc_call, WindowAccessible);
+	tc_call->SetName(wxT("Call sign"));
 	hsizer->Add(tc_call, 0, wxEXPAND, 0);
 	sizer->Add(hsizer, 0, wxLEFT|wxRIGHT|wxTOP|wxEXPAND, 10);
 	if (crq && crq->callSign[0])
@@ -212,9 +224,16 @@ CRQ_CallsignPage::CRQ_CallsignPage(CRQWiz *parent, TQSL_CERT_REQ *crq) :  CRQ_Pa
 
 	hsizer = new wxBoxSizer(wxHORIZONTAL);
 	hsizer->Add(dst, 0, wxRIGHT|wxALIGN_CENTER_VERTICAL, 5);
-	tc_dxcc = new wxOwnerDrawnComboBox(this, ID_CRQ_DXCC, wxT(""), wxDefaultPosition,
+#if  wxUSE_ACCESSIBILITY && __WXMAC__
+	tc_dxcc = new tqslComboBox(this, ID_CRQ_DXCC, wxT(""), wxDefaultPosition,
+		wxSize(em_w*25, -1), 0, 0, wxCB_DROPDOWN);
+#else
+	tc_dxcc = new tqslComboBox(this, ID_CRQ_DXCC, wxT(""), wxDefaultPosition,
 		wxSize(em_w*25, -1), 0, 0, wxCB_DROPDOWN|wxCB_READONLY);
+#endif
 	hsizer->Add(tc_dxcc, 1, 0, 0);
+	ACCESSIBLE(tc_dxcc, ComboBoxAx);
+	tc_dxcc->SetName(wxT("DXCC Entity"));
 	sizer->Add(hsizer, 0, wxALL, 10);
 
 	DXCC dx;
@@ -234,7 +253,7 @@ CRQ_CallsignPage::CRQ_CallsignPage(CRQWiz *parent, TQSL_CERT_REQ *crq) :  CRQ_Pa
 	if (i >= 0)
 		tc_dxcc->SetSelection(i);
 	struct {
-		wxOwnerDrawnComboBox **cb;
+		tqslComboBox **cb;
 		int id;
 	} boxes[][3] = {
 	    { {&tc_qsobeginy, ID_CRQ_QBYEAR}, {&tc_qsobeginm, ID_CRQ_QBMONTH}, {&tc_qsobegind, ID_CRQ_QBDAY} },
@@ -258,17 +277,23 @@ CRQ_CallsignPage::CRQ_CallsignPage(CRQWiz *parent, TQSL_CERT_REQ *crq) :  CRQ_Pa
 		sizer->Add(new wxStaticText(this, -1, label), 0, wxBOTTOM, 5);
 		hsizer = new wxBoxSizer(wxHORIZONTAL);
 		hsizer->Add(new wxStaticText(this, -1, wxT("Y")), 0, wxLEFT|wxALIGN_CENTER_VERTICAL, 20);
-		*(boxes[i][0].cb) = new wxOwnerDrawnComboBox(this, boxes[i][0].id, wxT(""), wxDefaultPosition,
-			wxSize(em_w*8, -1), 0, 0, wxCB_DROPDOWN|wxCB_READONLY);
+		*(boxes[i][0].cb) = new tqslComboBox(this, boxes[i][0].id, wxT(""), wxDefaultPosition,
+			wxSize(em_w*8, -1), 0, 0, wxCB_DROPDOWN/*|wxCB_READONLY*/);
 		hsizer->Add(*(boxes[i][0].cb), 0, wxLEFT, 5);
+		ACCESSIBLE(*(boxes[i][0].cb), ComboBoxAx);
+		(*boxes[i][0].cb)->SetName(i ? wxT("QSO End Year") : wxT("QSO Begin Year"));
 		hsizer->Add(new wxStaticText(this, -1, wxT("M")), 0, wxLEFT|wxALIGN_CENTER_VERTICAL, 10);
-		*(boxes[i][1].cb) = new wxOwnerDrawnComboBox(this, boxes[i][1].id, wxT(""), wxDefaultPosition,
-			wxSize(em_w*6, -1), 0, 0, wxCB_DROPDOWN|wxCB_READONLY);
+		*(boxes[i][1].cb) = new tqslComboBox(this, boxes[i][1].id, wxT(""), wxDefaultPosition,
+			wxSize(em_w*6, -1), 0, 0, wxCB_DROPDOWN/*|wxCB_READONLY*/);
 		hsizer->Add(*(boxes[i][1].cb), 0, wxLEFT, 5);
+		ACCESSIBLE(*(boxes[i][1].cb), ComboBoxAx);
+		(*boxes[i][1].cb)->SetName(i ? wxT("QSO End Month") : wxT("QSO Begin Month"));
 		hsizer->Add(new wxStaticText(this, -1, wxT("D")), 0, wxLEFT|wxALIGN_CENTER_VERTICAL, 10);
-		*(boxes[i][2].cb) = new wxOwnerDrawnComboBox(this, boxes[i][2].id, wxT(""), wxDefaultPosition,
-			wxSize(em_w*6, -1), 0, 0, wxCB_DROPDOWN|wxCB_READONLY);
+		*(boxes[i][2].cb) = new tqslComboBox(this, boxes[i][2].id, wxT(""), wxDefaultPosition,
+			wxSize(em_w*6, -1), 0, 0, wxCB_DROPDOWN/*|wxCB_READONLY*/);
 		hsizer->Add(*(boxes[i][2].cb), 0, wxLEFT, 5);
+		ACCESSIBLE(*(boxes[i][2].cb), ComboBoxAx);
+		(*boxes[i][2].cb)->SetName(i ? wxT("QSO End Day of Month") : wxT("QSO Begin Day of Month"));
 		int iofst = 0;
 		if (i > 0) {
 			iofst++;
@@ -389,6 +414,8 @@ CRQ_NamePage::CRQ_NamePage(CRQWiz *parent, TQSL_CERT_REQ *crq) :  CRQ_Page(paren
 	else if (config->Read(wxT("Name"), &val))
 		s = val;
 	tc_name = new wxTextCtrl(this, ID_CRQ_NAME, s, wxDefaultPosition, wxSize(def_w, -1));
+	ACCESSIBLE(tc_name, WindowAccessible);
+	tc_name->SetName(wxT("Name"));
 	hsizer->Add(tc_name, 1, 0, 0);
 	sizer->Add(hsizer, 0, wxALL, 10);
 	tc_name->SetMaxLength(TQSL_CRQ_NAME_MAX);
@@ -402,6 +429,8 @@ CRQ_NamePage::CRQ_NamePage(CRQWiz *parent, TQSL_CERT_REQ *crq) :  CRQ_Page(paren
 	hsizer->Add(new wxStaticText(this, -1, _("Address"), wxDefaultPosition, zst->GetSize(),
 		wxST_NO_AUTORESIZE|wxALIGN_RIGHT), 0, wxRIGHT|wxALIGN_CENTER_VERTICAL, 5);
 	tc_addr1 = new wxTextCtrl(this, ID_CRQ_ADDR1, s, wxDefaultPosition, wxSize(def_w, -1));
+	ACCESSIBLE(tc_addr1, WindowAccessible);
+	tc_addr1->SetName(wxT("Address line 1"));
 	hsizer->Add(tc_addr1, 1, 0, 0);
 	sizer->Add(hsizer, 0, wxLEFT|wxRIGHT|wxBOTTOM, 10);
 	tc_addr1->SetMaxLength(TQSL_CRQ_ADDR_MAX);
@@ -415,6 +444,8 @@ CRQ_NamePage::CRQ_NamePage(CRQWiz *parent, TQSL_CERT_REQ *crq) :  CRQ_Page(paren
 	hsizer->Add(new wxStaticText(this, -1, wxT(""), wxDefaultPosition, zst->GetSize(),
 		wxST_NO_AUTORESIZE|wxALIGN_RIGHT), 0, wxRIGHT, 5);
 	tc_addr2 = new wxTextCtrl(this, ID_CRQ_ADDR2, s, wxDefaultPosition, wxSize(def_w, -1));
+	ACCESSIBLE(tc_addr2, WindowAccessible);
+	tc_addr2->SetName(wxT("Address line 2"));
 	hsizer->Add(tc_addr2, 1, 0, 0);
 	sizer->Add(hsizer, 0, wxLEFT|wxRIGHT|wxBOTTOM, 10);
 	tc_addr2->SetMaxLength(TQSL_CRQ_ADDR_MAX);
@@ -428,6 +459,8 @@ CRQ_NamePage::CRQ_NamePage(CRQWiz *parent, TQSL_CERT_REQ *crq) :  CRQ_Page(paren
 	hsizer->Add(new wxStaticText(this, -1, _("City"), wxDefaultPosition, zst->GetSize(),
 		wxST_NO_AUTORESIZE|wxALIGN_RIGHT), 0, wxRIGHT|wxALIGN_CENTER_VERTICAL, 5);
 	tc_city = new wxTextCtrl(this, ID_CRQ_CITY, s, wxDefaultPosition, wxSize(def_w, -1));
+	ACCESSIBLE(tc_city, WindowAccessible);
+	tc_city->SetName(wxT("City"));
 	hsizer->Add(tc_city, 1, 0, 0);
 	sizer->Add(hsizer, 0, wxLEFT|wxRIGHT|wxBOTTOM, 10);
 	tc_city->SetMaxLength(TQSL_CRQ_CITY_MAX);
@@ -441,6 +474,8 @@ CRQ_NamePage::CRQ_NamePage(CRQWiz *parent, TQSL_CERT_REQ *crq) :  CRQ_Page(paren
 	hsizer->Add(new wxStaticText(this, -1, _("State"), wxDefaultPosition, zst->GetSize(),
 		wxST_NO_AUTORESIZE|wxALIGN_RIGHT), 0, wxRIGHT|wxALIGN_CENTER_VERTICAL, 5);
 	tc_state = new wxTextCtrl(this, ID_CRQ_STATE, s, wxDefaultPosition, wxSize(def_w, -1));
+	ACCESSIBLE(tc_state, WindowAccessible);
+	tc_state->SetName(wxT("State"));
 	hsizer->Add(tc_state, 1, 0, 0);
 	sizer->Add(hsizer, 0, wxLEFT|wxRIGHT|wxBOTTOM, 10);
 	tc_state->SetMaxLength(TQSL_CRQ_STATE_MAX);
@@ -454,6 +489,8 @@ CRQ_NamePage::CRQ_NamePage(CRQWiz *parent, TQSL_CERT_REQ *crq) :  CRQ_Page(paren
 	hsizer->Add(zst, 0, wxRIGHT|wxALIGN_CENTER_VERTICAL, 5);
 	tc_zip = new wxTextCtrl(this, ID_CRQ_ZIP, s, wxDefaultPosition, wxSize(def_w, -1));
 	hsizer->Add(tc_zip, 1, 0, 0);
+	ACCESSIBLE(tc_zip, WindowAccessible);
+	tc_zip->SetName(wxT("ZIP"));
 	sizer->Add(hsizer, 0, wxLEFT|wxRIGHT|wxBOTTOM, 10);
 	tc_zip->SetMaxLength(TQSL_CRQ_POSTAL_MAX);
 
@@ -466,6 +503,8 @@ CRQ_NamePage::CRQ_NamePage(CRQWiz *parent, TQSL_CERT_REQ *crq) :  CRQ_Page(paren
 	hsizer->Add(new wxStaticText(this, -1, _("Country"), wxDefaultPosition, zst->GetSize(),
 		wxST_NO_AUTORESIZE|wxALIGN_RIGHT), 0, wxRIGHT|wxALIGN_CENTER_VERTICAL, 5);
 	tc_country = new wxTextCtrl(this, ID_CRQ_COUNTRY, s, wxDefaultPosition, wxSize(def_w, -1));
+	ACCESSIBLE(tc_country, WindowAccessible);
+	tc_country->SetName(wxT("Country"));
 	hsizer->Add(tc_country, 1, 0, 0);
 	sizer->Add(hsizer, 0, wxLEFT|wxRIGHT|wxBOTTOM, 10);
 	tc_country->SetMaxLength(TQSL_CRQ_COUNTRY_MAX);
@@ -565,6 +604,8 @@ CRQ_EmailPage::CRQ_EmailPage(CRQWiz *parent, TQSL_CERT_REQ *crq) :  CRQ_Page(par
 	tc_email = new wxTextCtrl(this, ID_CRQ_EMAIL, s, wxDefaultPosition, wxSize(em_w*30, -1));
 	sizer->Add(tc_email, 0, wxLEFT|wxRIGHT|wxBOTTOM, 10);
 	tc_email->SetMaxLength(TQSL_CRQ_EMAIL_MAX);
+	ACCESSIBLE(tc_email, WindowAccessible);
+	tc_email->SetName(wxT("e-mail"));
 	wxStaticText *tc_warn = new wxStaticText(this, -1, _("Note: The e-mail address you provide here is the address to which the issued Certificate will be sent. Make sure it's the correct address!"));
 	sizer->Add(tc_warn, 0, wxALL, 10);
 	tc_warn->Wrap(_parent->maxWidth);
@@ -620,10 +661,14 @@ CRQ_PasswordPage::CRQ_PasswordPage(CRQWiz *parent) :  CRQ_Page(parent) {
 	sizer->Add(new wxStaticText(this, -1, _("Passphrase:")),
 		0, wxLEFT|wxRIGHT|wxTOP, 10);
 	tc_pw1 = new wxTextCtrl(this, ID_CRQ_PW1, wxT(""), wxDefaultPosition, wxSize(em_w*20, -1), wxTE_PASSWORD);
+	tc_pw1->SetName(wxT("Passphrase"));
+	ACCESSIBLE(tc_pw1, WindowAccessible);
 	sizer->Add(tc_pw1, 0, wxLEFT|wxRIGHT, 10);
 	sizer->Add(new wxStaticText(this, -1, _("Enter the passphrase again for verification:")),
 		0, wxLEFT|wxRIGHT|wxTOP, 10);
 	tc_pw2 = new wxTextCtrl(this, ID_CRQ_PW2, wxT(""), wxDefaultPosition, wxSize(em_w*20, -1), wxTE_PASSWORD);
+	ACCESSIBLE(tc_pw2, WindowAccessible);
+	tc_pw2->SetName(wxT("Repeat the Passphrase"));
 	sizer->Add(tc_pw2, 0, wxLEFT|wxRIGHT, 10);
 	wxStaticText *tc_pwwarn = new wxStaticText(this, -1, _("DO NOT lose the passphrase you choose! You will be unable to use the Certificate without this passphrase!"));
 	tc_pwwarn->Wrap(em_w * 40);
@@ -679,15 +724,13 @@ CRQ_SignPage::CRQ_SignPage(CRQWiz *parent, TQSL_CERT_REQ *crq)
 	_parent = parent;
 	wxBoxSizer *sizer = new wxBoxSizer(wxVERTICAL);
 
-	wxString itext;
-	itext = wxString(_("Is this new certificate for a callsign where you already have a "
-		"LoTW account, and you want the QSOs for this call to be added to an existing LoTW account? "));
-        itext += wxT("\n\n");
-	itext += _("If so, choose a callsign below for the primary LoTW account. If not, choose 'No', and a new LoTW account will be set up for these QSOs.");
+	introContent = wxString(_("Is this new certificate for a callsign where you already have a LoTW account, and you want the QSOs for this call to be added to an existing LoTW account? "));
+        introContent += wxT("\n\n");
+	introContent += _("If so, choose a callsign below for the primary LoTW account. If not, choose 'No', and a new LoTW account will be set up for these QSOs.");
 
-	itext += wxT("\n\n");
-	itext += _("CAUTION: Mixing QSOs for unrelated callsigns into one LoTW account can cause issues with handling awards.");
-	introText = new wxStaticText(this, -1, itext);
+	introContent += wxT("\n\n");
+	introContent += _("CAUTION: Mixing QSOs for unrelated callsigns into one LoTW account can cause issues with handling awards.");
+	introText = new wxStaticText(this, -1, introContent);
 	sizer->Add(introText);
 
 	wxSize sz = getTextSize(this);
@@ -705,6 +748,7 @@ CRQ_SignPage::CRQ_SignPage(CRQWiz *parent, TQSL_CERT_REQ *crq)
 		wxSize(em_w*30, em_h*8), wxTR_HAS_BUTTONS | wxSUNKEN_BORDER);
 	sizer->Add(cert_tree, 0, wxLEFT|wxRIGHT|wxBOTTOM|wxEXPAND);
 	cert_tree->SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOW));
+	ACCESSIBLE(cert_tree, TreeCtrlAx);
 	sizer->Add(tc_status, 0, wxALL|wxEXPAND, 10);
 	// Default to 'signed' unless there's no valid certificates to use for signing.
 	if (cert_tree->Build(0, &(_parent->provider)) > 0) {
@@ -714,10 +758,11 @@ CRQ_SignPage::CRQ_SignPage(CRQWiz *parent, TQSL_CERT_REQ *crq)
 		choice->SetSelection(1);
 		_parent->signIt = false;
 		cert_tree->Show(false);
-		introText->SetLabel(_("Since you have no callsign certificates, you must "
+		introContent = _("Since you have no callsign certificates, you must "
 					"submit an 'Unsigned' certificate request. This will allow you to "
 					"create your initial callsign certificate for LoTW use. "
-					"Click 'Finish' to complete this callsign certificate request."));
+					"Click 'Finish' to complete this callsign certificate request.");
+		introText->SetLabel(introContent);
 	}
 	introText->Wrap(em_w * 50);
 	AdjustPage(sizer, wxT("crq4.htm"));
@@ -727,9 +772,19 @@ CRQ_SignPage::CRQ_SignPage(CRQWiz *parent, TQSL_CERT_REQ *crq)
 void
 CRQ_SignPage::refresh() {
 	tqslTrace("CRQ_SignPage::refresh", NULL);
-	if (cert_tree->Build(0, &(_parent->provider)) > 0) {
+	if (cert_tree->Build(0, &(_parent->provider)) > 0 || _parent->forceSigning) {
 		choice->SetSelection(2);
 		_parent->signIt = true;
+		if (_parent->forceSigning) {
+			choice->SetSelection(2);
+			_parent->signIt = true;
+			cert_tree->Show(true);
+			choice->Enable(false);
+			introText->SetLabel(_("This portable callsign request requires approval using an existing callsign certificate"));
+		} else {
+			introText->SetLabel(introContent);
+			choice->Enable(true);
+		}
 	} else {
 		choice->SetSelection(1);
 		_parent->signIt = false;
@@ -925,6 +980,11 @@ CRQ_CallsignPage::validate() {
 	if (!_parent->usa || _parent->callsign.Len() != 3)
 		_parent->onebyone = false;
 
+	if (_parent->onebyone && !tqsl_isDateValid(&_parent->qsonotafter)) {
+		valMsg = _("US 1x1 callsign requests must provide an end date");
+		goto notok;
+	}
+
 	// Data looks okay, now let's make sure this isn't a duplicate request
 	// (unless it's a renewal).
 
@@ -1014,12 +1074,30 @@ CRQ_CallsignPage::validate() {
 			valMsg = wxString::Format(fmt, _parent->callsign.c_str(), _parent->callsign.c_str());
 		}
 	}
- notok:
+notok:
 	tc_status->SetLabel(valMsg);
 	tc_status->Wrap(_parent->maxWidth);
 	return 0;
 }
 
+static bool
+validCallSign(const string& call) {
+	// Check for invalid characters
+	if (call.find_first_not_of("ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789/") != string::npos)
+		return false;
+	// Need at least one letter
+	if (call.find_first_of("ABCDEFGHIJKLMNOPQRSTUVWXYZ") == string::npos)
+		return false;
+	// Need at least one number
+	size_t num;
+	if ((num = call.find_first_of("0123456789")) == string::npos)
+		return false;
+	// At least one letter after the number - catches "/KP4" for example
+	if (call.find_first_of("ABCDEFGHIJKLMNOPQRSTUVWXYZ", num) == string::npos)
+		return false;
+	return true;
+}
+
 bool
 CRQ_CallsignPage::TransferDataFromWindow() {
 	tqslTrace("CRQ_CallsignPage::TransferDataFromWindow", NULL);
@@ -1030,6 +1108,8 @@ CRQ_CallsignPage::TransferDataFromWindow() {
 	bool hasEndDate = (!tqsl_isDateNull(&_parent->qsonotafter) && tqsl_isDateValid(&_parent->qsonotafter));
 	bool notInULS = false;
 
+	_parent->forceSigning = false;
+
 	// First check if there's a slash. If so, it's a portable. Use the base callsign
 	wxString callsign = _parent->callsign;
 	int slashpos = callsign.Find('/', true);
@@ -1037,10 +1117,26 @@ CRQ_CallsignPage::TransferDataFromWindow() {
 	wxString suffix = wxT("");
 	if (slashpos != wxNOT_FOUND) {
 		prefix = callsign.Left(slashpos);
-		suffix = callsign.Right(slashpos+1);
+		suffix = callsign.Right(callsign.Len() - slashpos - 1);
 		callsign = prefix;
 	}
 
+	// Shuffle time. Is one of these a valid callsign?
+	if (!suffix.IsEmpty()) {
+		// Is the prefix valid? If so, OK.
+		if (!validCallSign(std::string(prefix.mb_str()))) {
+			// Else how about suffix?
+			if (validCallSign(std::string(suffix.mb_str()))) {
+				callsign = suffix;
+				suffix = prefix;
+				prefix = callsign;
+			}
+		}
+		if (!validCallSign(std::string(prefix.mb_str()))) {
+			_parent->usa = false;
+		}
+	}
+
 	// Is this in the ULS?
 	if (valMsg.Len() == 0 && _parent->usa && !_parent->onebyone) {
 		wxString name, attn, addr1, city, state, zip, update;
@@ -1101,18 +1197,17 @@ CRQ_CallsignPage::TransferDataFromWindow() {
 					notInULS = true;
 					break;
 				}
-				// If this call has a slash, then it may be a portable call from
-				// outside the US. We really can't tell at this point so just
-				// let it go.
-				if (slashpos != wxNOT_FOUND) {
-					break;
-				}
 				valMsg = wxString::Format(_("The callsign %s is not currently registered in the FCC ULS database as of %s.\nIf this is a newly registered call, you must wait at least one business day for it to be valid. Please enter a currently valid callsign."), callsign.c_str(), update.c_str());
 				break;
 		}
 	}
-
 	if (valMsg.Len() == 0) {
+		// If this call has a slash, then it may be a portable call from
+		// outside the US. We really can't tell at this point so just
+		// let it go.
+		if (!suffix.IsEmpty()) {
+			_parent->forceSigning = true;
+		}
 		ok = true;
 	} else {
 		wxMessageBox(valMsg, _("Error"), wxOK | wxICON_ERROR, this);
@@ -1138,7 +1233,15 @@ CRQ_CallsignPage::TransferDataFromWindow() {
 		}
 	}
 
-	if (ok && hasEndDate && !notInULS) {		// If it has an end date and it's a current call
+	if (ok && _parent->forceSigning) {
+		if (!_parent->validcerts) {
+			wxString msg = _("You cannot request a certificate for a portable callsign as you must sign those requests, but you have no valid Callsign Certificates that you can use to sign this request.");
+			wxMessageBox(msg, _("TQSL Error"), wxOK | wxICON_ERROR, this);
+			return false;
+		}
+	}
+
+	if (ok && hasEndDate && !notInULS && !_parent->onebyone) {	// If it has an end date and it's a current call
 		wxString msg = _("You have chosen a QSO end date for this Callsign Certificate. The 'QSO end date' should ONLY be set if that date is the date when that callsign's license expired or the license was replaced by a new callsign.");
 			msg += wxT("\n\n");
 			msg += _("If you set an end date, you will not be able to sign QSOs past that date, even if the Callsign Certificate itself is still valid.");
