@@ -29,7 +29,7 @@
 #include "wx/radiobox.h"
 
 #include "wx/wxhtml.h"
-#include "wx/odcombo.h"
+#include "wx/combobox.h"
 
 #include "certtree.h"
 
@@ -90,6 +90,7 @@ class CRQWiz : public ExtWizard {
 	CRQ_Page *signPage;
 	tQSL_Cert cert;
 	TQSL_CERT_REQ *_crq;
+	bool forceSigning;	// Portable call, non-US. Require signing
 
  private:
 	CRQ_Page *_first;
@@ -110,7 +111,7 @@ class CRQ_ProviderPage : public CRQ_Page {
 	void DoUpdateInfo();
 	void UpdateInfo(wxCommandEvent&);
 	vector<TQSL_PROVIDER> providers;
-	wxOwnerDrawnComboBox *tc_provider;
+	tqslComboBox *tc_provider;
 	wxStaticText *tc_provider_info;
 
 	DECLARE_EVENT_TABLE()
@@ -123,10 +124,11 @@ class CRQ_CallsignPage : public CRQ_Page {
 	virtual const char *validate();
 	virtual CRQ_Page *GetPrev() const;
 	virtual CRQ_Page *GetNext() const;
+
  private:
 	wxTextCtrl *tc_call;
-	wxOwnerDrawnComboBox *tc_qsobeginy, *tc_qsobeginm, *tc_qsobegind, *tc_dxcc;
-	wxOwnerDrawnComboBox *tc_qsoendy, *tc_qsoendm, *tc_qsoendd;
+	tqslComboBox *tc_qsobeginy, *tc_qsobeginm, *tc_qsobegind, *tc_dxcc;;
+	tqslComboBox *tc_qsoendy, *tc_qsoendm, *tc_qsoendd;
 	wxStaticText *tc_status;
 	bool initialized;		// Set true when validating makes sense
 	int em_w;
@@ -211,6 +213,7 @@ class CRQ_SignPage : public CRQ_Page {
 	CRQWiz *_parent;
 	wxRadioBox *choice;
 	wxStaticText* introText;
+	wxString introContent;
 	DECLARE_EVENT_TABLE()
 };
 
